pub enum Error {
Show 16 variants
ConnectionError(String),
ConfigError(String),
IoError(ErrorKind, String),
SerializationError(Error),
ProtocolError(ProtocolError),
ServerError(String),
AuthenticationFailed(String),
InvalidResponse,
ResponseTooLarge(usize, usize),
RequestTooLarge(usize, usize),
CircuitBreakerOpen(String),
PoolExhausted(String),
AllServersUnavailable,
Timeout,
TimeoutWithMessage(String),
Other(String),
}Variants
ConnectionError(String)
ConfigError(String)
IoError(ErrorKind, String)
SerializationError(Error)
ProtocolError(ProtocolError)
ServerError(String)
AuthenticationFailed(String)
InvalidResponse
ResponseTooLarge(usize, usize)
RequestTooLarge(usize, usize)
CircuitBreakerOpen(String)
PoolExhausted(String)
Timeout
TimeoutWithMessage(String)
Other(String)
Implementations
Sourceimpl Error
impl Error
Sourcepub fn is_retriable(&self) -> bool
pub fn is_retriable(&self) -> bool
Classify whether this error is retriable.
Permanent errors (not retriable) include authentication failures, configuration errors, and server-side rejections for invalid topics, producer fencing, authorization failures, etc.
Transient errors (retriable) include I/O errors, connection resets, timeouts, and generic server errors that may resolve after reconnect.